@@ -4,13 +4,17 @@ import logging
 import time
 
 import requests
+import zope.interface
 from certbot import errors
+from certbot import interfaces
 from certbot.plugins import dns_common
 
 logger = logging.getLogger(__name__)
 logger.setLevel(logging.DEBUG)
 
 
+@zope.interface.implementer(interfaces.IAuthenticator)  # needed for compatibility with older certbots, see #13
+@zope.interface.provider(interfaces.IPluginFactory)  # needed for compatibility with older certbots, see #13
 class Authenticator(dns_common.DNSAuthenticator):
     """DNS Authenticator for deSEC
 
@@ -39,10 +43,9 @@ class Authenticator(dns_common.DNSAuthenticator):
 
     def _setup_credentials(self):
         self.credentials = self._configure_credentials(
-            "credentials",
-            "deSEC credentials INI file",
-            {
-                "endpoint": "URL of the deSEC API.",
+            key="credentials",
+            label="deSEC credentials INI file",
+            required_variables={
                 "token": "Access token for deSEC API.",
             },
         )
@@ -87,15 +90,17 @@ class _DesecConfigClient(object):
 
     @staticmethod
     def desec_request(method, **kwargs):
-        response: requests.Response = method(**kwargs)
-        if response.status_code == 429 and 'Retry-After' in response.headers:
-            try:
-                cooldown = int(response.headers['Retry-After'])
-            except ValueError:
+        for _ in range(3):
+            response: requests.Response = method(**kwargs)
+            if response.status_code == 429 and 'Retry-After' in response.headers:
+                try:
+                    cooldown = int(response.headers['Retry-After'])
+                except ValueError:
+                    return response
+                logger.debug(f"deSEC API limit reached. Retrying request after {cooldown}s.")
+                time.sleep(cooldown)
+            else:
                 return response
-            logger.debug(f"deSEC API limit reached. Retrying request after {cooldown}s.")
-            time.sleep(cooldown)
-            response = method(**kwargs)
         return response
 
     def desec_get(self, **kwargs):
